/*
 * P E R U N -- a physically based lightning generator
 * Master's thesis
 * Department of Computer Graphics and Interaction
 * Faculty of Electrical Engineering
 * Czech Technical University in Prague.
 *
 * Supervisor: Ing. Jaroslav Sloup
 *
 * Distributed under the GNU General Public License v3.0
 * */

/**
 * @file
 * @author Richard Dobrichovsky <dobrichovsky@gmail.com>
 * @date May 2016
 * 
 * @brief Declarations for the DAG class.
 *
 * Declarations for the DAG class implementing a graph data structure to represent the generated lightning shape.
 *
 * */

#include <vector>
#include <random>
#include <iostream>
#include <fstream>
#include <string>

/**
 * Node of graph data structure to the generated lightning shape. Actually not a directed acyclic graph but a tree.
 * @brief Node of graph data structure to the generated lightning shape.
 * */
class DAG
{
public:
	DAG(int id, DAG * parent, int y, int x,  int width, int height, int resolutionMultiple);
	DAG(int id, double x, double y, int type, double luminance);
	~DAG();
	void saveGraph(int frame);
	/// This node's parent.
	DAG * parent;
	/// This node's children.
	std::vector<DAG*> children;
	/// Node id referring to simulation grid pixel.
	int id;
	/// Node x coordinate with jitter.
	double x;
	/// Node y coordinate with jitter.
	double y;
	/// Node type (1, 2 or 3 -- main channel, secondary or ternary branch respectively).
	int type;
	/// Node luminance.
	double luminance;
private:
	void saveVertex();
	void saveEdge();
};