/*
 * P E R U N -- a physically based lightning generator
 * Master's thesis
 * Department of Computer Graphics and Interaction
 * Faculty of Electrical Engineering
 * Czech Technical University in Prague.
 *
 * Supervisor: Ing. Jaroslav Sloup
 *
 * Distributed under the GNU General Public License v3.0
 * */

/**
 * @file
 * @author Richard Dobrichovsky <dobrichovsky@gmail.com>
 * @date May 2016
 * 
 * @brief Project header file.
 * 
 * Header file for project, currently only including documentation.
 *
 *
 * @mainpage
 * @section sec_intro Introduction
 *
 * Perun is a physically based lightning generator developed as part of Richard Dobrichovsky's master's thesis at the Department of Computer Graphics and Interaction, Faculty of Electrical Engineering, Czech Technical University in Prague. This standalone application allows the user to generate several kinds of lightning through several intuitive user controls.
 * 
 * @section sec_compile Installation
 *
 * The project is written in C++ and was developed and tested in Microsoft Visual Studio 2010, project files for which are included for compilation within Visual Studio. Apart from that, a Makefile is provided for compilation with gcc on Linux.
 *
 * The program uses several libraries: Tinyexr, a header only library for EXR image manipulation located in the ./include directory; Eigen, a library for linear algebra, left for the user to install; and finally CUDA, also left for the user to install.
 *
 * Compiled 64-bit binaries are included for Microsoft Windows and Linux. Tested on Windows 7 and Ubuntu 14.04 LTS.
 *
 * @section sec_usage Usage
 * 
 * Perun can be run without any parameters: as such it will generate one frame on a 64x128 simulation grid with low branching using the prog2 solver.
 *
 * Furthermore, the user can custimise the output through user runtime parameters:\n
 * <tt>-e ETA            Branching factor. ETA = 1 more branching, ETA = 2 less branching.\n
   -f FRAMES         Number of frames to animate.\n
   -g                Do not generate new shape.\n
	-h HEIGHT         Simulation grid height.\n
	-l1 LUMINANCE     Luminance of main channel. Default = 4.0.\n
	-l2 LUMINANCE     Luminance of secondary channels. Secondary channels are those longer than TYPE_2_CUTTOFF. Default LUMINANCE = 1.0.\n
	-l3 LUMINANCE     Luminance of ternary channels. Ternary channels are all others.\n
	-r RESOLUTION     Resolution multiplicator of rendered image. Resulting image width will be WIDTH * RESOLUTION. Default RESOLUTION = 8.\n
	-s SOLVER         Solver to use. Valid options regular, eigen, prog2 or cuda.\n
	-t2 TYPE_2_CUTOFF Secondary channels cuttof. Default TYPE_2_CUTOFF = 20.\n
	-w WIDTH          Simulation grid width.\n</tt>
 * */